//
//  RWTCenteredScrollView.m
//  ImageScroller
//
//  Created by Main Account on 4/21/14.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

#import "RWTCenteredScrollView.h"

@interface RWTCenteredScrollView()
@property (nonatomic, assign) BOOL firstTime;
@end

@implementation RWTCenteredScrollView

- (id)initWithFrame:(CGRect)frame
{
  self = [super initWithFrame:frame];
  if (self) {
    // Initialization code
    self.firstTime = YES;
  }
  return self;
}

- (void)layoutSubviews {

  [super layoutSubviews];
  
  if (self.firstTime) {
    [self setZoomScales];
  }
  
  [self centerContent];
  
  if (self.firstTime) {
    self.firstTime = NO;
  }
  
}

- (void)centerContent {

  if ([self.delegate respondsToSelector:@selector(viewForZoomingInScrollView:)]) {
  
    UIView *viewToCenter = [self.delegate viewForZoomingInScrollView:self];
  
    // center the view as it becomes smaller than the size of the screen
    CGSize boundsSize = self.bounds.size;
    CGRect frameToCenter = viewToCenter.frame;
    
    // center horizontally
    if (frameToCenter.size.width < boundsSize.width) {
      frameToCenter.origin.x = (boundsSize.width - frameToCenter.size.width) / 2;
    } else {
      frameToCenter.origin.x = 0;
    }
    
    // center vertically
    if (frameToCenter.size.height < boundsSize.height) {
      frameToCenter.origin.y = (boundsSize.height - frameToCenter.size.height) / 2;
    } else {
      frameToCenter.origin.y = 0;
    }
    
    viewToCenter.frame = frameToCenter;
  }
}

- (void)setZoomScales {

  if ([self.delegate respondsToSelector:@selector(viewForZoomingInScrollView:)]) {
  
    UIView *viewToCenter = [self.delegate viewForZoomingInScrollView:self];

    CGSize boundsSize = self.bounds.size;
    CGSize contentSize = viewToCenter.bounds.size;
    
    CGFloat xScale = boundsSize.width / contentSize.width; // the scale needed to perfectly fit the image width-wise
    CGFloat yScale = boundsSize.height / contentSize.height; // the scale needed to perfectly fit the iamge height-wise
    CGFloat minScale = MIN(xScale, yScale);
    
    self.minimumZoomScale = minScale;
    self.zoomScale = minScale;
    self.maximumZoomScale = 3.0;
    
  }

}

@end
